function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/// <reference path="index.d.ts" />
import React, { Component } from 'react';
import { View, TextInput, TouchableWithoutFeedback, Keyboard, Platform, I18nManager } from 'react-native';
import Clipboard from '@react-native-clipboard/clipboard';
import styles from './styles';
import { isAutoFillSupported } from './helpers/device';
import { codeToArray } from './helpers/codeToArray';
export default class OTPInputView extends Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "fields", []);

    _defineProperty(this, "keyboardDidHideListener", void 0);

    _defineProperty(this, "timer", void 0);

    _defineProperty(this, "hasCheckedClipBoard", void 0);

    _defineProperty(this, "clipBoardCode", void 0);

    _defineProperty(this, "copyCodeFromClipBoardOnAndroid", () => {
      if (Platform.OS === 'android') {
        this.checkPinCodeFromClipBoard();
        this.timer = setInterval(this.checkPinCodeFromClipBoard, 400);
      }
    });

    _defineProperty(this, "bringUpKeyBoardIfNeeded", () => {
      const {
        autoFocusOnLoad,
        pinCount
      } = this.props;
      const digits = this.getDigits();
      const focusIndex = digits.length ? digits.length - 1 : 0;

      if (focusIndex < pinCount && autoFocusOnLoad) {
        this.focusField(focusIndex);
      }
    });

    _defineProperty(this, "getDigits", () => {
      const {
        digits: innerDigits
      } = this.state;
      const {
        code
      } = this.props;
      return code === undefined ? innerDigits : code.split('');
    });

    _defineProperty(this, "handleKeyboardDidHide", () => {
      this.blurAllFields();
    });

    _defineProperty(this, "notifyCodeChanged", () => {
      const {
        digits
      } = this.state;
      const code = digits.join('');
      const {
        onCodeChanged
      } = this.props;

      if (onCodeChanged) {
        onCodeChanged(code);
      }
    });

    _defineProperty(this, "checkPinCodeFromClipBoard", () => {
      const {
        pinCount,
        onCodeFilled
      } = this.props;
      const regexp = new RegExp(`^\\d{${pinCount}}$`);
      Clipboard.getString().then(code => {
        if (this.hasCheckedClipBoard && regexp.test(code) && this.clipBoardCode !== code) {
          this.setState({
            digits: code.split('')
          }, () => {
            this.blurAllFields();
            this.notifyCodeChanged();
            onCodeFilled && onCodeFilled(code);
          });
        }

        this.clipBoardCode = code;
        this.hasCheckedClipBoard = true;
      }).catch(() => {});
    });

    _defineProperty(this, "handleChangeText", (index, text) => {
      var _newdigits$index;

      const {
        onCodeFilled,
        pinCount
      } = this.props;
      const digits = this.getDigits();
      let newdigits = digits.slice();
      const oldTextLength = ((_newdigits$index = newdigits[index]) === null || _newdigits$index === void 0 ? void 0 : _newdigits$index.length) ?? 0;
      const newTextLength = text.length;

      if (newTextLength - oldTextLength === pinCount) {
        // user pasted text in.
        newdigits = text.split('').slice(oldTextLength, newTextLength);
        this.setState({
          digits: newdigits
        }, this.notifyCodeChanged);
      } else {
        if (text.length === 0) {
          if (newdigits.length > 0) {
            newdigits = newdigits.slice(0, newdigits.length - 1);
          }
        } else {
          text.split('').forEach(value => {
            if (index < pinCount) {
              newdigits[index] = value;
              index += 1;
            }
          });
          index -= 1;
        }

        this.setState({
          digits: newdigits
        }, this.notifyCodeChanged);
      }

      let result = newdigits.join('');

      if (result.length >= pinCount) {
        onCodeFilled && onCodeFilled(result);
        this.focusField(pinCount - 1);
        this.blurAllFields();
      } else {
        if (text.length > 0 && index < pinCount - 1) {
          this.focusField(index + 1);
        }
      }
    });

    _defineProperty(this, "handleKeyPressTextInput", (index, key) => {
      const digits = this.getDigits();

      if (key === 'Backspace') {
        if (!digits[index] && index > 0) {
          this.handleChangeText(index - 1, '');
          this.focusField(index - 1);
        }
      }
    });

    _defineProperty(this, "focusField", index => {
      if (index < this.fields.length && this.fields[index]) {
        this.fields[index].focus();
        this.setState({
          selectedIndex: index
        });
      }
    });

    _defineProperty(this, "blurAllFields", () => {
      this.fields.forEach(field => field.blur());
      this.setState({
        selectedIndex: -1
      });
    });

    _defineProperty(this, "clearAllFields", () => {
      const {
        clearInputs,
        code
      } = this.props;

      if (clearInputs && !code) {
        this.setState({
          digits: [],
          selectedIndex: 0
        });
      }
    });

    _defineProperty(this, "renderOneInputField", (_, index) => {
      const {
        codeInputFieldStyle,
        codeInputHighlightStyle,
        secureTextEntry,
        editable,
        keyboardType,
        selectionColor,
        keyboardAppearance,
        autoFillCode,
        clearInputs
      } = this.props;
      const {
        defaultTextFieldStyle
      } = styles;
      const {
        selectedIndex,
        digits
      } = this.state;
      const {
        placeholderCharacter,
        placeholderTextColor,
        maxLength
      } = this.props;
      const {
        color: defaultPlaceholderTextColor
      } = { ...defaultTextFieldStyle,
        ...codeInputFieldStyle
      };
      return /*#__PURE__*/React.createElement(View, {
        pointerEvents: "none",
        key: index + 'view',
        testID: "inputSlotView"
      }, /*#__PURE__*/React.createElement(TextInput, {
        testID: "textInput",
        underlineColorAndroid: "rgba(0,0,0,0)",
        style: selectedIndex === index ? [defaultTextFieldStyle, codeInputFieldStyle, codeInputHighlightStyle] : [defaultTextFieldStyle, codeInputFieldStyle],
        ref: ref => {
          this.fields[index] = ref;
        },
        onChangeText: text => {
          this.handleChangeText(index, text);
        },
        maxLength: maxLength,
        onKeyPress: _ref => {
          let {
            nativeEvent: {
              key
            }
          } = _ref;
          this.handleKeyPressTextInput(index, key);
        },
        value: !clearInputs ? digits[index] : '',
        keyboardAppearance: keyboardAppearance,
        keyboardType: keyboardType,
        textContentType: autoFillCode && isAutoFillSupported ? 'oneTimeCode' : 'none',
        key: index,
        selectionColor: selectionColor,
        secureTextEntry: secureTextEntry,
        editable: editable,
        placeholder: placeholderCharacter,
        placeholderTextColor: placeholderTextColor || defaultPlaceholderTextColor
      }));
    });

    _defineProperty(this, "renderTextFields", () => {
      const {
        pinCount
      } = this.props;
      const array = new Array(pinCount).fill(0);
      return array.map(this.renderOneInputField);
    });

    const {
      code: _code
    } = props;
    this.state = {
      digits: codeToArray(_code),
      selectedIndex: props.autoFocusOnLoad ? 0 : -1
    };
  }

  UNSAFE_componentWillReceiveProps(nextProps) {
    const {
      code
    } = this.props;

    if (nextProps.code !== code) {
      this.setState({
        digits: codeToArray(nextProps.code)
      });
    }
  }

  componentDidMount() {
    this.copyCodeFromClipBoardOnAndroid();
    setTimeout(() => this.bringUpKeyBoardIfNeeded(), 100);
    this.keyboardDidHideListener = Keyboard.addListener('keyboardDidHide', this.handleKeyboardDidHide);
  }

  componentWillUnmount() {
    var _this$keyboardDidHide;

    if (this.timer) {
      clearInterval(this.timer);
    }

    (_this$keyboardDidHide = this.keyboardDidHideListener) === null || _this$keyboardDidHide === void 0 ? void 0 : _this$keyboardDidHide.remove();
  }

  render() {
    const {
      pinCount,
      style,
      clearInputs
    } = this.props;
    const digits = this.getDigits();
    return /*#__PURE__*/React.createElement(View, {
      testID: "OTPInputView",
      style: style
    }, /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
      style: {
        width: '100%',
        height: '100%'
      },
      onPress: () => {
        if (!clearInputs) {
          let filledPinCount = digits.filter(digit => {
            return digit !== null && digit !== undefined;
          }).length;
          this.focusField(Math.min(filledPinCount, pinCount - 1));
        } else {
          this.clearAllFields();
          this.focusField(0);
        }
      }
    }, /*#__PURE__*/React.createElement(View, {
      style: {
        flexDirection: I18nManager.isRTL ? 'row-reverse' : 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        width: '100%',
        height: '100%'
      }
    }, this.renderTextFields())));
  }

}

_defineProperty(OTPInputView, "defaultProps", {
  pinCount: 6,
  autoFocusOnLoad: true,
  secureTextEntry: false,
  editable: true,
  keyboardAppearance: 'default',
  keyboardType: 'number-pad',
  clearInputs: false,
  placeholderCharacter: '',
  selectionColor: '#000',
  maxLength: 1,
  autoFillCode: true
});
//# sourceMappingURL=index.js.map